@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rd.h,v 1.173 2007/07/10 19:07:54 fredg Exp $
+//      $Id: rd.h,v 1.187 2008-07-31 13:38:46 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,11 +23,6 @@
 #ifndef RD_H
 #define RD_H
 
-/*
- * Current Database Version
- */
-#define RD_VERSION_DATABASE 139
-
 /*
  * Default Configuration File
  */
@@ -65,10 +60,35 @@
 #define DEFAULT_MYSQL_USERNAME "rduser"
 #define DEFAULT_MYSQL_PASSWORD "letmein"
 #define DEFAULT_MYSQL_DRIVER "QMYSQL3"
-#define DEFAULT_MYSQL_HEARTBEAT_INTERVAL 300
+#define DEFAULT_MYSQL_HEARTBEAT_INTERVAL 360
 #define MYSQL_BUILTIN_DATABASE "mysql"
 #define POSTGRESQL_BUILTIN_DATABASE "template1"
 
+/*
+ * Default Logging Settings
+ */
+#define DEFAULT_LOG_FACILITY "syslog"
+#define DEFAULT_LOG_CORE_DUMP_DIRECTORY "/"
+#define DEFAULT_LOG_PATTERN "%n-%Y%M%d.log"
+
+/*
+ * ALSA Settings
+ */
+#define RD_ALSA_DEFAULT_PERIOD_QUANTITY 2
+#define RD_ALSA_DEFAULT_PERIOD_SIZE 1024
+#define RD_ALSA_FADE_INTERVAL 100
+#define RD_ALSA_SAMPLE_RATE_TOLERANCE 100
+
+/*
+ * Date Limits
+ */
+#define RD_MAX_YEAR 8000
+
+/*
+ * JACK Settings
+ */
+#define RD_JACK_FADE_INTERVAL 100
+
 /*
  * RIPCD TCP Port
  */
@@ -92,7 +112,7 @@
 /*
  * Max number of possible GPIO lines (GPI OR GPO)
  */
-#define MAX_GPIO_PINS 192
+#define MAX_GPIO_PINS 32768
 
 /*
  * Max number of possible workstations
@@ -274,13 +294,14 @@ struct RDMeterBlock {
 /*
  * The fade profile (for HPI adapters only)
  */
-#define RD_FADE_TYPE RHPISoundCard::Log
+#define RD_FADE_TYPE RDHPISoundCard::Log
 
 /*
  * The limits on timescaling
  */
-#define RD_TIMESCALE_MIN 0.8
-#define RD_TIMESCALE_MAX 1.2
+#define RD_TIMESCALE_MIN 0.833
+#define RD_TIMESCALE_MAX 1.250
+#define RD_TIMESCALE_DIVISOR 100000.0
 
 /*
  * Max number of default services
@@ -368,5 +389,39 @@ struct RDMeterBlock {
 #define RD_LINUX_EDITOR "xterm -e vi"
 #define RD_WIN32_EDITOR "notepad"
 
+/*
+ * System-wide Maintenance Interval (mS)
+ */
+#define RD_MAINT_MIN_INTERVAL 900000
+#define RD_MAINT_MAX_INTERVAL 3600000
+
+/*
+ * Audio File Filter for QFileDialog
+ */
+#define RD_AUDIO_FILE_FILTER "Sound Files (*.mp* *.MP* *.wav *.WAV *.ogg *.OGG *.flac *.FLAC *.atx *.ATX *.tmc *.TMC)\nWAV Files (*.wav *.WAV)\nMPEG Files (*.mp* *.MP*)\nOggVorbis Files (*.ogg *.OGG)\nFLAC Files (*.flac *.FLAC)\nATX Files (*.atx *.ATX)\nTM Century GoldDrive Files (*.tmc *.TMC)\nAll Files (*.*)"
+
+/*
+ * Image File Filter for QFileDialog
+ */
+#define RD_IMAGE_FILE_FILTER "Image Files (*.png *.bmp *.xbm *.xpm *.pbm *.pgm *.ppm *.jpg *.mng *.gif *.PNG *.BMP *.XBM *.XPM *.PBM *.PGM *.PPM *.JPG *.MNG *.GIF)\nAll Files (*.*)"
+
+/*
+ * Web Interface Settings
+ */
+#define RD_WEB_BACKGROUND_COLOR "#FFFFFF"
+#define RD_WEB_LINE_COLOR1 "#E0E0E0"
+#define RD_WEB_LINE_COLOR2 "#F0F0F0"
+
+/*
+ * LiveWire Values
+ */
+#define RD_LIVEWIRE_DEFAULT_TCP_PORT 93
+#define RD_LIVEWIRE_DEFAULT_STREAM_PORT 5004
+#define RD_LIVEWIRE_DEFAULT_CHANNELS 2
+#define RD_LIVEWIRE_MAX_CMD_LENGTH 1024
+#define RD_LIVEWIRE_GPIO_BUNDLE_SIZE 5
+#define RD_LIVEWIRE_DEFAULT_LOAD RDLiveWireDestination::LoadHighZ
+#define RD_LIVEWIRE_MAX_SOURCE 0x7FFF
+
 
 #endif  // RD_H
