@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlibrary_conf.h,v 1.17 2007/02/14 21:48:41 fredg Exp $
+//      $Id: rdlibrary_conf.h,v 1.19 2008-08-04 19:05:33 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,7 +31,7 @@ class RDLibraryConf
 {
  public:
   enum RecordMode {Manual=0,Vox=1};
-  RDLibraryConf(QString station,unsigned instance);
+  RDLibraryConf(const QString &station,unsigned instance);
   QString station() const;
   unsigned instance() const;
   int inputCard() const;
@@ -72,13 +72,15 @@ class RDLibraryConf
   void setRipperLevel(int level) const;
   QString cddbServer() const;
   void setCddbServer(QString server) const;
+  bool enableEditor() const;
+  void setEnableEditor(bool state) const;
   void getSettings(RDSettings *s) const;
 
  private:
-  void SetRow(QString param,int value) const;
-  void SetRow(QString param,unsigned value) const;
-  void SetRow(QString param,QString value) const;
-  void SetRow(QString param,bool value) const;
+  void SetRow(const QString &param,int value) const;
+  void SetRow(const QString &param,unsigned value) const;
+  void SetRow(const QString &param,const QString &value) const;
+  void SetRow(const QString &param,bool value) const;
   QString lib_station;
   unsigned lib_instance;
   unsigned lib_id;
