@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: add_station.cpp,v 1.19 2007/02/14 21:51:01 fredg Exp $
+//      $Id: add_station.cpp,v 1.26 2007-11-12 18:43:28 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,9 +31,9 @@
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
-#include <rconf.h>
-#include <math.h>
+
+#include <rddb.h>
+#include <rdairplay_conf.h>
 
 #include <edit_station.h>
 #include <add_station.h>
@@ -72,7 +72,7 @@ AddStation::AddStation(QString *stationname,QWidget *parent,const char *name)
   //
   add_name_edit=new QLineEdit(this,"add_name_edit");
   add_name_edit->setGeometry(130,10,sizeHint().width()-140,19);
-  add_name_edit->setMaxLength(20);
+  add_name_edit->setMaxLength(64);
   add_name_edit->setValidator(validator);
   QLabel *label=new QLabel(add_name_edit,tr("New &Host Name:"),this,"label");
   label->setGeometry(10,10,115,19);
@@ -115,7 +115,7 @@ AddStation::AddStation(QString *stationname,QWidget *parent,const char *name)
   //
   add_exemplar_box->insertItem(tr("Empty Host Config"));
   QString sql="select NAME from STATIONS";
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
     add_exemplar_box->insertItem(q->value(0).toString());
   }
@@ -143,8 +143,8 @@ QSizePolicy AddStation::sizePolicy() const
 
 void AddStation::okData()
 {
-  QSqlQuery *q;
-  QSqlQuery *q1;
+  RDSqlQuery *q;
+  RDSqlQuery *q1;
   QString sql;
 
   if(add_name_edit->text().isEmpty()) {
@@ -159,7 +159,7 @@ void AddStation::okData()
                            DEFAULT_NAME=\"user\"",
 			  (const char *)add_name_edit->text(),
 			  (const char *)add_name_edit->text());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(!q->isActive()) {
       QMessageBox::warning(this,tr("Host Exists"),tr("Host Already Exists!"),
 			   1,0,0);
@@ -172,32 +172,34 @@ void AddStation::okData()
     // Create Service Perms
     //
     sql="select NAME from SERVICES";
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into SERVICE_PERMS set\
                            SERVICE_NAME=\"%s\",STATION_NAME=\"%s\"",
 			    (const char *)q->value(0).toString(),
 			    (const char *)add_name_edit->text());
-      q1=new QSqlQuery(sql);
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
   }
   else {    // Use Specified Config
-    sql=QString().sprintf("select DEFAULT_NAME from STATIONS\
+    sql=QString().sprintf("select DEFAULT_NAME,STARTUP_CART from STATIONS\
                            where NAME=\"%s\"",
 			  (const char *)add_exemplar_box->currentText());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(q->first()) {
       sql=QString().sprintf("insert into STATIONS set NAME=\"%s\",\
                              DESCRIPTION=\"Workstation %s\",\
                              USER_NAME=\"%s\",\
-                             DEFAULT_NAME=\"%s\"",
+                             DEFAULT_NAME=\"%s\",\
+                             STARTUP_CART=%u",
 			    (const char *)add_name_edit->text(),
 			    (const char *)add_name_edit->text(),
 			    (const char *)q->value(0).toString(),
-			    (const char *)q->value(0).toString());
-      q1=new QSqlQuery(sql);
+			    (const char *)q->value(0).toString(),
+			    q->value(1).toUInt());
+      q1=new RDSqlQuery(sql);
       if(!q1->isActive()) {
 	QMessageBox::warning(this,tr("Host Exists"),tr("Host Already Exists!"),
 			     1,0,0);
@@ -215,13 +217,13 @@ void AddStation::okData()
     sql=QString().sprintf("select SERVICE_NAME from SERVICE_PERMS\
                            where STATION_NAME=\"%s\"",
 			  (const char *)add_exemplar_box->currentText());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into SERVICE_PERMS set\
                              STATION_NAME=\"%s\",SERVICE_NAME=\"%s\"",
 			    (const char *)add_name_edit->text(),
 			    (const char *)q->value(0).toString());
-      q1=new QSqlQuery(sql);
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -238,7 +240,7 @@ void AddStation::okData()
                            RIPPER_LEVEL,CDDB_SERVER from RDLIBRARY\
                            where (STATION=\"%s\")&&(INSTANCE=0)",
 			  (const char *)add_exemplar_box->currentText());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(q->first()) {
       sql=QString().sprintf("insert into RDLIBRARY set\
                              INPUT_CARD=%d,INPUT_PORT=%d,INPUT_TYPE=%d,\
@@ -272,7 +274,7 @@ void AddStation::okData()
 			    q->value(18).toInt(),
 			    (const char *)q->value(19).toString(),
 			    (const char *)add_name_edit->text());
-      q1=new QSqlQuery(sql);
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -289,7 +291,7 @@ void AddStation::okData()
                            RIPPER_LEVEL,DEFAULT_TRANS_TYPE from RDLOGEDIT\
                            where (STATION=\"%s\")",
 			  (const char *)add_exemplar_box->currentText());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(q->first()) {
       sql=QString().sprintf("insert into RDLOGEDIT set\
                              INPUT_CARD=%d,INPUT_PORT=%d,\
@@ -325,7 +327,7 @@ void AddStation::okData()
 			    q->value(15).toInt(),
 			    q->value(16).toInt(),
 			    q->value(17).toInt());
-      q1=new QSqlQuery(sql);
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -339,7 +341,7 @@ void AddStation::okData()
                            DEFAULT_THRESHOLD,DEFAULT_MONITOR_ON from DECKS\
                            where STATION_NAME=\"%s\"",
 			  (const char *)add_exemplar_box->currentText());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(q->first()) {
       sql=QString().sprintf("insert into DECKS set\
                              CHANNEL=%u,CARD_NUMBER=%d,PORT_NUMBER=%d,\
@@ -360,7 +362,7 @@ void AddStation::okData()
 			    q->value(9).toInt(),
 			    (const char *)add_name_edit->text(),
                             (const char *)q->value(10).toString());
-      q1=new QSqlQuery(sql);
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -382,11 +384,11 @@ void AddStation::okData()
                            START_RML2,STOP_RML2,START_RML3,STOP_RML3,\
                            START_RML4,STOP_RML4,START_RML5,STOP_RML5,\
                            START_RML6,STOP_RML6,START_RML7,STOP_RML7,\
-                           START_RML8,STOP_RML8,START_RML9,STOP_RML9 \
-                           from RDAIRPLAY \
+                           START_RML8,STOP_RML8,START_RML9,STOP_RML9,\
+                           BUTTON_LABEL_TEMPLATE,EXIT_PASSWORD from RDAIRPLAY \
                            where (STATION=\"%s\")&&(INSTANCE=0)",
 			  (const char *)add_exemplar_box->currentText());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(q->first()) {
       sql=QString().sprintf("insert into RDAIRPLAY set\
                              CARD0=%d,PORT0=%d,CARD1=%d,PORT1=%d,\
@@ -426,7 +428,9 @@ void AddStation::okData()
                              START_RML8=\"%s\",\
                              STOP_RML8=\"%s\",\
                              START_RML9=\"%s\",\
-                             STOP_RML9=\"%s\"",
+                             STOP_RML9=\"%s\",\
+                             BUTTON_LABEL_TEMPLATE=\"%s\",\
+                             EXIT_PASSWORD=\"%s\"",
 			    q->value(0).toInt(),
 			    q->value(1).toInt(),
 			    q->value(2).toInt(),
@@ -488,8 +492,80 @@ void AddStation::okData()
 			    (const char *)q->value(57).toString(),
 			    (const char *)q->value(58).toString(),
 			    (const char *)q->value(59).toString(),
-			    (const char *)q->value(60).toString());
-      q1=new QSqlQuery(sql);
+			    (const char *)q->value(60).toString(),
+			    (const char *)q->value(61).toString(),
+			    (const char *)q->value(62).toString());
+      q1=new RDSqlQuery(sql);
+      delete q1;
+    }
+    delete q;
+
+    //
+    // Clone RDPanel Config
+    //
+    sql=QString().sprintf("select CARD2,PORT2,CARD6,PORT6,\
+                           CARD7,PORT7,CARD8,PORT8,CARD9,PORT9,\
+                           STATION_PANELS,\
+                           USER_PANELS,CLEAR_FILTER,\
+                           FLASH_PANEL,\
+                           DEFAULT_SERVICE,\
+                           START_RML2,STOP_RML2,\
+                           START_RML6,STOP_RML6,START_RML7,STOP_RML7,\
+                           START_RML8,STOP_RML8,START_RML9,STOP_RML9,\
+                           BUTTON_LABEL_TEMPLATE from RDPANEL \
+                           where (STATION=\"%s\")&&(INSTANCE=0)",
+			  (const char *)add_exemplar_box->currentText());
+    q=new RDSqlQuery(sql);
+    if(q->first()) {
+      sql=QString().sprintf("insert into RDPANEL set\
+                             CARD2=%d,PORT2=%d,CARD6=%d,PORT6=%d,\
+                             CARD7=%d,PORT7=%d,CARD8=%d,PORT8=%d,\
+                             CARD9=%d,PORT9=%d,\
+                             STATION_PANELS=%d,\
+                             USER_PANELS=%d,\
+                             CLEAR_FILTER=\"%s\",\
+                             FLASH_PANEL=\"%s\",\
+                             STATION=\"%s\",\
+                             DEFAULT_SERVICE=\"%s\",\
+                             START_RML2=\"%s\",\
+                             STOP_RML2=\"%s\",\
+                             START_RML6=\"%s\",\
+                             STOP_RML6=\"%s\",\
+                             START_RML7=\"%s\",\
+                             STOP_RML7=\"%s\",\
+                             START_RML8=\"%s\",\
+                             STOP_RML8=\"%s\",\
+                             START_RML9=\"%s\",\
+                             STOP_RML9=\"%s\",\
+                             BUTTON_LABEL_TEMPLATE=\"%s\"",
+			    q->value(0).toInt(),
+			    q->value(1).toInt(),
+			    q->value(2).toInt(),
+			    q->value(3).toInt(),
+			    q->value(4).toInt(),
+			    q->value(5).toInt(),
+			    q->value(6).toInt(),
+			    q->value(7).toInt(),
+			    q->value(8).toInt(),
+			    q->value(9).toInt(),
+			    q->value(10).toInt(),
+			    q->value(11).toInt(),
+			    (const char *)q->value(12).toString(),
+			    (const char *)q->value(13).toString(),
+			    (const char *)add_name_edit->text(),
+			    (const char *)q->value(14).toString(),
+			    (const char *)q->value(15).toString(),
+			    (const char *)q->value(16).toString(),
+			    (const char *)q->value(17).toString(),
+			    (const char *)q->value(18).toString(),
+			    (const char *)q->value(19).toString(),
+			    (const char *)q->value(20).toString(),
+			    (const char *)q->value(21).toString(),
+			    (const char *)q->value(22).toString(),
+			    (const char *)q->value(23).toString(),
+			    (const char *)q->value(24).toString(),
+			    (const char *)q->value(25).toString());
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -506,7 +582,7 @@ void AddStation::okData()
     sql=sql.left(sql.length()-1);
     sql+=QString().sprintf(" from AUDIO_PORTS where STATION_NAME=\"%s\"",
 			   (const char *)add_exemplar_box->currentText());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into AUDIO_PORTS set\
                              CARD_NUMBER=%u,CLOCK_SOURCE=%d,\
@@ -523,7 +599,7 @@ void AddStation::okData()
 			       i,q->value(5+3*i).toInt());
       }
       sql=sql.left(sql.length()-1);
-      q1=new QSqlQuery(sql);
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -535,7 +611,7 @@ void AddStation::okData()
                            STOP_BITS,PARITY,TERMINATION from TTYS\
                            where STATION_NAME=\"%s\"",
 			  (const char *)add_exemplar_box->currentText());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into TTYS set\
                              PORT_ID=%u,ACTIVE=\"%s\",PORT=\"%s\",\
@@ -550,7 +626,7 @@ void AddStation::okData()
 			    q->value(6).toInt(),
 			    q->value(7).toInt(),
 			    (const char *)add_name_edit->text());
-      q1=new QSqlQuery(sql);
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -560,10 +636,12 @@ void AddStation::okData()
     //
     sql=QString().sprintf("select NAME,MATRIX,TYPE,PORT_TYPE,CARD,PORT,\
                            IP_ADDRESS,IP_PORT,USERNAME,PASSWORD,GPIO_DEVICE,\
-                           INPUTS,OUTPUTS,GPIS,GPOS,DISPLAYS,FADERS \
+                           INPUTS,OUTPUTS,GPIS,GPOS,DISPLAYS,FADERS,\
+                           PORT_TYPE_2,PORT_2,IP_ADDRESS_2,IP_PORT_2,\
+                           USERNAME_2,PASSWORD_2 \
                            from MATRICES where STATION_NAME=\"%s\"",
 			  (const char *)add_exemplar_box->currentText());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into MATRICES set\
                              NAME=\"%s\",MATRIX=%d,TYPE=%d,PORT_TYPE=%d,\
@@ -571,7 +649,9 @@ void AddStation::okData()
                              USERNAME=\"%s\",PASSWORD=\"%s\",\
                              GPIO_DEVICE=\"%s\",INPUTS=%d,OUTPUTS=%d,GPIS=%d,\
                              GPOS=%d,DISPLAYS=%d,STATION_NAME=\"%s\",\
-                             FADERS=%d",
+                             FADERS=%d,PORT_TYPE_2=%d,PORT_2=%d,\
+                             IP_ADDRESS_2=\"%s\",IP_PORT_2=%d,\
+                             USERNAME_2=\"%s\",PASSWORD_2=\"%s\"",
 			    (const char *)q->value(0).toString(),
 			    q->value(1).toInt(),
 			    q->value(2).toInt(),
@@ -589,8 +669,14 @@ void AddStation::okData()
 			    q->value(14).toInt(),
 			    q->value(15).toInt(),
 			    (const char *)add_name_edit->text(),
-			    q->value(16).toInt());
-      q1=new QSqlQuery(sql);
+			    q->value(16).toInt(),
+			    q->value(17).toInt(),
+			    q->value(18).toInt(),
+			    (const char *)q->value(19).toString(),
+			    q->value(20).toInt(),
+			    (const char *)q->value(21).toString(),
+			    (const char *)q->value(22).toString());
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -602,7 +688,7 @@ void AddStation::okData()
                            ENGINE_NUM,DEVICE_NUM from INPUTS\
                            where STATION_NAME=\"%s\"",
 			  (const char *)add_exemplar_box->currentText());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into INPUTS set\
                              MATRIX=%d,NUMBER=%d,NAME=\"%s\",FEED_NAME=\"%s\",\
@@ -616,7 +702,7 @@ void AddStation::okData()
 			    q->value(5).toInt(),
 			    q->value(6).toInt(),
 			    (const char *)add_name_edit->text());
-      q1=new QSqlQuery(sql);
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -628,7 +714,7 @@ void AddStation::okData()
                            ENGINE_NUM,DEVICE_NUM from OUTPUTS\
                            where STATION_NAME=\"%s\"",
 			  (const char *)add_exemplar_box->currentText());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into OUTPUTS set\
                              MATRIX=%d,NUMBER=%d,NAME=\"%s\",\
@@ -640,7 +726,7 @@ void AddStation::okData()
 			    q->value(3).toInt(),
 			    q->value(4).toInt(),
 			    (const char *)add_name_edit->text());
-      q1=new QSqlQuery(sql);
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -651,7 +737,7 @@ void AddStation::okData()
     sql=QString().sprintf("select MATRIX,NUMBER,MACRO_CART from GPIS\
                            where STATION_NAME=\"%s\"",
 			  (const char *)add_exemplar_box->currentText());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into GPIS set\
                              MATRIX=%d,NUMBER=%d,MACRO_CART=%d,\
@@ -660,7 +746,7 @@ void AddStation::okData()
 			    q->value(1).toInt(),
 			    q->value(2).toInt(),
 			    (const char *)add_name_edit->text());
-      q1=new QSqlQuery(sql);
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -672,7 +758,7 @@ void AddStation::okData()
                            DEVICE_NUM,SURFACE_NUM,RELAY_NUM,BUSS_NUM\
                            from VGUEST_RESOURCES where STATION_NAME=\"%s\"",
 			  (const char *)add_exemplar_box->currentText());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into VGUEST_RESOURCES set\
                              MATRIX_NUM=%d,VGUEST_TYPE=%d,NUMBER=%d,\
@@ -687,7 +773,7 @@ void AddStation::okData()
 			    q->value(6).toInt(),
 			    q->value(7).toInt(),
 			    (const char *)add_name_edit->text());
-      q1=new QSqlQuery(sql);
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -698,7 +784,7 @@ void AddStation::okData()
     sql=QString().sprintf("select NAME,VARVALUE,REMARK from HOSTVARS\
                            where STATION_NAME=\"%s\"",
 			  (const char *)add_exemplar_box->currentText());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into HOSTVARS set\
                              NAME=\"%s\",VARVALUE=\"%s\",REMARK=\"%s\",\
@@ -707,7 +793,56 @@ void AddStation::okData()
 			    (const char *)q->value(1).toString(),
 			    (const char *)q->value(2).toString(),
 			    (const char *)add_name_edit->text());
-      q1=new QSqlQuery(sql);
+      q1=new RDSqlQuery(sql);
+      delete q1;
+    }
+    delete q;
+
+    //
+    // Clone System Panels
+    //
+    sql=QString().sprintf("select PANEL_NO,ROW_NO,COLUMN_NO,LABEL,CART,\
+                           DEFAULT_COLOR from PANELS where \
+                           (TYPE=%d && OWNER=\"%s\")",
+			  RDAirPlayConf::StationPanel,
+			  (const char *)add_exemplar_box->currentText());
+    q=new RDSqlQuery(sql);
+    while(q->next()) {
+      sql=QString().sprintf("insert into PANELS set PANEL_NO=%d,ROW_NO=%d,\
+                             COLUMN_NO=%d,LABEL=\"%s\",CART=%u,\
+                             DEFAULT_COLOR=\"%s\",TYPE=%d,OWNER=\"%s\"",
+			    q->value(0).toInt(),
+			    q->value(1).toInt(),
+			    q->value(2).toInt(),
+			    (const char *)q->value(3).toString(),
+			    q->value(4).toUInt(),
+			    (const char *)q->value(5).toString(),
+			    RDAirPlayConf::StationPanel,
+			    (const char *)add_name_edit->text());
+      q1=new RDSqlQuery(sql);
+      delete q1;
+    }
+    delete q;
+
+    sql=QString().sprintf("select PANEL_NO,ROW_NO,COLUMN_NO,LABEL,CART,\
+                           DEFAULT_COLOR from EXTENDED_PANELS where \
+                           (TYPE=%d && OWNER=\"%s\")",
+			  RDAirPlayConf::StationPanel,
+			  (const char *)add_exemplar_box->currentText());
+    q=new RDSqlQuery(sql);
+    while(q->next()) {
+      sql=QString().sprintf("insert into EXTENDED_PANELS set PANEL_NO=%d,\
+                             ROW_NO=%d,COLUMN_NO=%d,LABEL=\"%s\",CART=%u,\
+                             DEFAULT_COLOR=\"%s\",TYPE=%d,OWNER=\"%s\"",
+			    q->value(0).toInt(),
+			    q->value(1).toInt(),
+			    q->value(2).toInt(),
+			    (const char *)q->value(3).toString(),
+			    q->value(4).toUInt(),
+			    (const char *)q->value(5).toString(),
+			    RDAirPlayConf::StationPanel,
+			    (const char *)add_name_edit->text());
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
