@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_station.cpp,v 1.39 2007/09/14 14:06:26 fredg Exp $
+//      $Id: edit_station.cpp,v 1.47 2008-08-18 20:26:15 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,8 +29,8 @@
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
 
+#include <rddb.h>
 #include <rdconf.h>
 #include <rdcatch_connect.h>
 #include <rdcart_dialog.h>
@@ -54,7 +54,7 @@
 EditStation::EditStation(QString display,QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
   int item=0;
   char temp[256];
@@ -129,31 +129,60 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   station_default_name_label->setFont(font);
   station_default_name_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
+  //
+  // Broadcast security model
+  //
+  station_broadcast_sec_edit=new QComboBox(this,"station_broadcast_sec_edit");
+  station_broadcast_sec_edit->setGeometry(115,74,140,19);
+  // Index values should match RDStation class enum and database schema.
+  station_broadcast_sec_edit->insertItem(tr("Host"),0);
+  station_broadcast_sec_edit->insertItem(tr("User"),1);
+  station_broadcast_sec_edit->setEditable(false);
+  QLabel *station_broadcast_sec_label=new QLabel(station_broadcast_sec_edit,
+					   tr("Security Model:"),this,
+					   "station_broadcast_sec_label");
+  station_broadcast_sec_label->setGeometry(10,74,100,19);
+  station_broadcast_sec_label->setFont(font);
+  station_broadcast_sec_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
   //
   // Station IP Address
   //
   station_address_edit=new QLineEdit(this,"station_address_edit");
-  station_address_edit->setGeometry(115,74,120,19);
+  station_address_edit->setGeometry(115,95,120,19);
   station_address_edit->setMaxLength(15);
   station_address_edit->setValidator(validator);
   QLabel *station_address_label=new QLabel(station_address_edit,
 					   tr("&IP Address:"),this,
 					   "station_address_label");
-  station_address_label->setGeometry(10,74,100,19);
+  station_address_label->setGeometry(10,95,100,19);
   station_address_label->setFont(font);
   station_address_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
+  //
+  // Station Editor Command
+  //
+  station_editor_cmd_edit=new QLineEdit(this,"station_editor_cmd_edit");
+  station_editor_cmd_edit->setGeometry(115,116,sizeHint().width()-130,19);
+  station_editor_cmd_edit->setMaxLength(255);
+  QLabel *station_editor_cmd_label=new QLabel(station_editor_cmd_edit,
+					   tr("Editor &Command:"),this,
+					   "station_editor_cmd_label");
+  station_editor_cmd_label->setGeometry(10,116,100,19);
+  station_editor_cmd_label->setFont(font);
+  station_editor_cmd_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
   //
   // Station Time Offset
   //
   station_timeoffset_box=new QSpinBox(this,"station_timeoffset_box");
-  station_timeoffset_box->setGeometry(115,95,80,19);
+  station_timeoffset_box->setGeometry(115,137,80,19);
   station_timeoffset_box->setRange(-RD_MAX_TIME_OFFSET,RD_MAX_TIME_OFFSET);
   station_timeoffset_box->setSuffix(tr(" mS"));
   QLabel *station_timeoffset_label=new QLabel(station_timeoffset_box,
 					     tr("&Time Offset:"),this,
 					     "station_timeoffset_label");
-  station_timeoffset_label->setGeometry(10,95,100,19);
+  station_timeoffset_label->setGeometry(10,137,100,19);
   station_timeoffset_label->setFont(font);
   station_timeoffset_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
@@ -161,50 +190,62 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   // Startup Cart
   //
   station_startup_cart_edit=new QLineEdit(this,"station_startup_cart_edit");
-  station_startup_cart_edit->setGeometry(115,116,60,19);
+  station_startup_cart_edit->setGeometry(115,158,60,19);
   station_startup_cart_edit->setMaxLength(15);
   station_startup_cart_edit->setValidator(new QIntValidator(1,999999,this));
   QLabel *station_startup_cart_label=new QLabel(station_startup_cart_edit,
 					   tr("&Startup Cart:"),this,
 					   "station_startup_cart_label");
-  station_startup_cart_label->setGeometry(10,116,100,19);
+  station_startup_cart_label->setGeometry(10,158,100,19);
   station_startup_cart_label->setFont(font);
   station_startup_cart_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   QPushButton *select_button=
     new QPushButton(tr("Select"),this,"select_button");
   select_button->setFont(small_font);
-  select_button->setGeometry(180,115,50,22);
+  select_button->setGeometry(180,157,50,22);
   connect(select_button,SIGNAL(clicked()),this,SLOT(selectClicked()));
 
   //
   // Heartbeat Checkbox
   //
   station_heartbeat_box=new QCheckBox(this,"station_heartbeat_box");
-  station_heartbeat_box->setGeometry(10,137,15,15);
+  station_heartbeat_box->setGeometry(10,182,15,15);
   QLabel *label=new QLabel(station_heartbeat_box,
 			   tr("Enable Heartbeat"),this,
 			   "station_heartbeat_label");
-  label->setGeometry(30,135,150,20);
+  label->setGeometry(30,180,150,20);
   label->setFont(font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
   connect(station_heartbeat_box,SIGNAL(toggled(bool)),
 	  this,SLOT(heartbeatToggledData(bool)));
 
+  //
+  // Filter Checkbox
+  //
+  station_filter_box=new QCheckBox(this,"station_filter_box");
+  station_filter_box->setGeometry(210,182,15,15);
+  label=new QLabel(station_filter_box,
+		   tr("Use Realtime Filtering"),this,
+		   "station_filter_label");
+  label->setGeometry(230,180,150,20);
+  label->setFont(font);
+  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+
   //
   // Heartbeat Cart
   //
   station_hbcart_edit=new QLineEdit(this,"station_hbcart_edit");
-  station_hbcart_edit->setGeometry(65,156,60,19);
+  station_hbcart_edit->setGeometry(65,204,60,19);
   station_hbcart_edit->setReadOnly(true);
   station_hbcart_label=new QLabel(station_hbcart_edit,
 				  tr("Cart:"),this,
 				  "station_hbcart_label");
-  station_hbcart_label->setGeometry(10,156,50,19);
+  station_hbcart_label->setGeometry(10,204,50,19);
   station_hbcart_label->setFont(font);
   station_hbcart_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
   station_hbcart_button=new QPushButton(this,"station_hbcart_button");
-  station_hbcart_button->setGeometry(140,153,60,26);
+  station_hbcart_button->setGeometry(140,201,60,26);
   station_hbcart_button->setFont(font);
   station_hbcart_button->setText(tr("Select"));
   connect(station_hbcart_button,SIGNAL(clicked()),
@@ -214,17 +255,17 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   // Heartbeat Interval
   //
   station_hbinterval_spin=new QSpinBox(this,"station_hbinterval_spin");
-  station_hbinterval_spin->setGeometry(275,156,45,19);
+  station_hbinterval_spin->setGeometry(275,204,45,19);
   station_hbinterval_spin->setRange(1,300);
   station_hbinterval_label=new QLabel(station_hbinterval_spin,
 				  tr("Interval:"),this,
 				  "station_hbinterval_label");
-  station_hbinterval_label->setGeometry(220,156,50,19);
+  station_hbinterval_label->setGeometry(220,204,50,19);
   station_hbinterval_label->setFont(font);
   station_hbinterval_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
   station_hbinterval_unit=new QLabel(tr("secs"),
 				     this,"station_hbinterval_unit");
-  station_hbinterval_unit->setGeometry(325,156,100,19);
+  station_hbinterval_unit->setGeometry(325,204,100,19);
   station_hbinterval_unit->setFont(font);
   station_hbinterval_unit->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -232,7 +273,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  RDLibrary Configuration Button
   //
   QPushButton *button=new QPushButton(this,"library_button");
-  button->setGeometry(10,189,80,50);
+  button->setGeometry(10,237,80,50);
   button->setFont(font);
   button->setText(tr("RD&Library"));
   connect(button,SIGNAL(clicked()),this,SLOT(editLibraryData()));
@@ -241,7 +282,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  RDCatch Configuration Button
   //
   button=new QPushButton(this,"tty_button");
-  button->setGeometry(100,189,80,50);
+  button->setGeometry(100,237,80,50);
   button->setFont(font);
   button->setText(tr("RDCatch"));
   connect(button,SIGNAL(clicked()),this,SLOT(editDeckData()));
@@ -250,7 +291,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  RDAirPlay Configuration Button
   //
   button=new QPushButton(this,"airplay_button");
-  button->setGeometry(190,189,80,50);
+  button->setGeometry(190,237,80,50);
   button->setFont(font);
   button->setText(tr("RDAirPlay"));
   connect(button,SIGNAL(clicked()),this,SLOT(editAirPlayData()));
@@ -259,7 +300,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  RDPanel Configuration Button
   //
   button=new QPushButton(this,"rdpanel_button");
-  button->setGeometry(280,189,80,50);
+  button->setGeometry(280,237,80,50);
   button->setFont(font);
   button->setText(tr("RDPanel"));
   connect(button,SIGNAL(clicked()),this,SLOT(editPanelData()));
@@ -268,7 +309,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  RDLogEdit Configuration Button
   //
   button=new QPushButton(this,"logedit_button");
-  button->setGeometry(10,249,80,50);
+  button->setGeometry(10,297,80,50);
   button->setFont(font);
   button->setText(tr("RDLogEdit"));
   connect(button,SIGNAL(clicked()),this,SLOT(editLogEditData()));
@@ -277,43 +318,16 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   // Dropboxes Configuration Button
   //
   button=new QPushButton(this,"dropboxes_button");
-  button->setGeometry(100,249,80,50);
+  button->setGeometry(100,297,80,50);
   button->setFont(font);
   button->setText(tr("Dropboxes"));
   connect(button,SIGNAL(clicked()),this,SLOT(editDropboxesData()));
 
-  //
-  //  View Adapters Configuration Button
-  //
-  button=new QPushButton(this,"airplay_button");
-  button->setGeometry(190,309,80,50);
-  button->setFont(font);
-  button->setText(tr("Audio\nResources"));
-  connect(button,SIGNAL(clicked()),this,SLOT(viewAdaptersData()));
-
-  //
-  //  Audio Ports Configuration Button
-  //
-  button=new QPushButton(this,"audio_ports_button");
-  button->setGeometry(10,309,80,50);
-  button->setFont(font);
-  button->setText(tr("Audio\nPorts"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editAudioData()));
-
-  //
-  //  TTY Configuration Button
-  //
-  button=new QPushButton(this,"tty_button");
-  button->setGeometry(100,309,80,50);
-  button->setFont(font);
-  button->setText(tr("Serial\nPorts"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editTtyData()));
-
   //
   //  Switcher Configuration Button
   //
   button=new QPushButton(this,"switcher_button");
-  button->setGeometry(190,249,80,50);
+  button->setGeometry(190,297,80,50);
   button->setFont(font);
   button->setText(tr("Switchers\nGPIO"));
   connect(button,SIGNAL(clicked()),this,SLOT(editSwitcherData()));
@@ -322,16 +336,43 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  Host Variables Configuration Button
   //
   button=new QPushButton(this,"hostvars_button");
-  button->setGeometry(280,249,80,50);
+  button->setGeometry(280,297,80,50);
   button->setFont(font);
   button->setText(tr("Host\nVariables"));
   connect(button,SIGNAL(clicked()),this,SLOT(editHostvarsData()));
 
+  //
+  //  Audio Ports Configuration Button
+  //
+  button=new QPushButton(this,"audio_ports_button");
+  button->setGeometry(10,357,80,50);
+  button->setFont(font);
+  button->setText(tr("Audio\nPorts"));
+  connect(button,SIGNAL(clicked()),this,SLOT(editAudioData()));
+
+  //
+  //  TTY Configuration Button
+  //
+  button=new QPushButton(this,"tty_button");
+  button->setGeometry(100,357,80,50);
+  button->setFont(font);
+  button->setText(tr("Serial\nPorts"));
+  connect(button,SIGNAL(clicked()),this,SLOT(editTtyData()));
+
+  //
+  //  View Adapters (Audio Resources) Configuration Button
+  //
+  button=new QPushButton(this,"view_adapters_button");
+  button->setGeometry(190,357,80,50);
+  button->setFont(font);
+  button->setText(tr("Audio\nResources"));
+  connect(button,SIGNAL(clicked()),this,SLOT(viewAdaptersData()));
+
   //
   // Backups Configuration Button
   //
   button=new QPushButton(this,"backup_button");
-  button->setGeometry(280,309,80,50);
+  button->setGeometry(280,357,80,50);
   button->setFont(font);
   button->setText(tr("Backups"));
   connect(button,SIGNAL(clicked()),this,SLOT(editBackupsData()));
@@ -362,13 +403,14 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   station_name_edit->setText(station_station->name());
   station_description_edit->setText(station_station->description());
   station_address_edit->setText(station_station->address().toString());
+  station_editor_cmd_edit->setText(station_station->editorPath());
   station_timeoffset_box->setValue(station_station->timeOffset());
   unsigned cartnum=station_station->startupCart();
   if(cartnum>0) {
     station_startup_cart_edit->setText(QString().sprintf("%06u",cartnum));
   }
   sql="select LOGIN_NAME from USERS";
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     station_default_name_edit->insertItem(q->value(0).toString());
     if(q->value(0).toString()==station_station->defaultName()) {
@@ -376,6 +418,9 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
     }
     item++;
   }
+  station_broadcast_sec_edit->
+    setCurrentItem((RDStation::BroadcastSecurityMode)station_station->
+                     broadcastSecurity());
   if((cartnum=station_station->heartbeatCart())>0) {
     station_heartbeat_box->setChecked(true);
     station_hbcart_edit->setText(QString().sprintf("%u",cartnum));
@@ -387,6 +432,15 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
     station_heartbeat_box->setChecked(false);
     heartbeatToggledData(false);
   }
+  switch(station_station->filterMode()) {
+    case RDStation::FilterSynchronous:
+      station_filter_box->setChecked(true);
+      break;
+
+    case RDStation::FilterAsynchronous:
+      station_filter_box->setChecked(false);
+      break;
+  }
   delete q;
 
 }
@@ -401,14 +455,9 @@ void EditStation::selectClicked()
 {
   int cartnum;
 
-  RDCartDialog *dialog=new RDCartDialog(&cartnum,&station_cart_filter,
-					&station_cart_group,
-					RDCart::Macro,NULL,0,
-					this);
-  if(dialog->exec()==0) {
+  if(admin_cart_dialog->exec(&cartnum,RDCart::Macro,NULL,0)==0) {
     station_startup_cart_edit->setText(QString().sprintf("%06d",cartnum));
   }
-  delete dialog;
 }
 
 
@@ -427,20 +476,15 @@ void EditStation::heartbeatClickedData()
 {
   int cartnum;
 
-  RDCartDialog *dialog=new RDCartDialog(&cartnum,&station_cart_filter,
-					&station_cart_group,
-					RDCart::Macro,NULL,0,
-					this,"heartbeat_dialog");
-  if(dialog->exec()==0) {
+  if(admin_cart_dialog->exec(&cartnum,RDCart::Macro,NULL,0)==0) {
     station_hbcart_edit->setText(QString().sprintf("%06d",cartnum));
   }
-  delete dialog;
 }
 
 
 QSize EditStation::sizeHint() const
 {
-  return QSize(375,439);
+  return QSize(375,487);
 } 
 
 
@@ -478,7 +522,12 @@ void EditStation::okData()
   }
   station_station->setDescription(station_description_edit->text());
   station_station->setDefaultName(station_default_name_edit->currentText());
+  station_station->
+    setBroadcastSecurity((RDStation::BroadcastSecurityMode)
+                           station_broadcast_sec_edit->currentItem());
   station_station->setAddress(addr);
+  station_station->
+    setEditorPath(station_editor_cmd_edit->text());
   station_station->setTimeOffset(station_timeoffset_box->value());
   cartnum=station_startup_cart_edit->text().toUInt(&ok);
   if(ok&&(cartnum<=999999)) {
@@ -487,6 +536,12 @@ void EditStation::okData()
   else {
     station_station->setStartupCart(0);
   }
+  if(station_filter_box->isChecked()) {
+    station_station->setFilterMode(RDStation::FilterSynchronous);
+  }
+  else {
+    station_station->setFilterMode(RDStation::FilterAsynchronous);
+  }
   station_catch_connect->reloadHeartbeat();
   station_catch_connect->reloadOffset();
 
