@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdadmin.cpp,v 1.62 2007/12/31 18:49:09 fredg Exp $
+//      $Id: rdadmin.cpp,v 1.64 2008-08-18 20:26:16 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -59,6 +59,8 @@
 #include <info_dialog.h>
 #include <createdb.h>
 
+#include <rdescape_string.h>
+
 //
 // Icons
 //
@@ -509,20 +511,20 @@ int gui_main(int argc,char *argv[])
 	  ".");
   a.installTranslator(&qt);
 
-  QTranslator libradio(0);
-  libradio.load(QString(PREFIX)+QString("/share/srlabs/libradio_")+
-		QTextCodec::locale(),".");
-  a.installTranslator(&libradio);
-
-  QTranslator librhpi(0);
-  librhpi.load(QString(PREFIX)+QString("/share/srlabs/librhpi_")+
-	       QTextCodec::locale(),".");
-  a.installTranslator(&librhpi);
-
-  QTranslator tests(0);
-  tests.load(QString(PREFIX)+QString("/share/srlabs/rdadmin_")+
+  QTranslator rd(0);
+  rd.load(QString(PREFIX)+QString("/share/rivendell/librd_")+
 	     QTextCodec::locale(),".");
-  a.installTranslator(&tests);
+  a.installTranslator(&rd);
+
+  QTranslator rdhpi(0);
+  rdhpi.load(QString(PREFIX)+QString("/share/rivendell/librdhpi_")+
+	     QTextCodec::locale(),".");
+  a.installTranslator(&rdhpi);
+
+  QTranslator tr(0);
+  tr.load(QString(PREFIX)+QString("/share/rivendell/rdadmin_")+
+	  QTextCodec::locale(),".");
+  a.installTranslator(&tr);
 
   //
   // Start Event Loop
