@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdairplay.h,v 1.77 2007/12/05 20:17:33 fredg Exp $
+//      $Id: rdairplay.h,v 1.79 2008-04-20 19:17:35 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -78,6 +78,7 @@
 #define MESSAGE_WIDGET_WIDTH 410
 #define RDAIRPLAY_USAGE "[<log-spec>=[:<nextline>[+]]] [...]\n\nWhere <log-spec> refers to one of the three log machines\n('--log1', '--log2' or '--log3') and <nextline> to the line number\nto do a 'make next' to after the log is loaded (default = 0). If the\n'+' is appended, then the log is started after the 'make next'.\n\nExamples:\n rdairplay --log1=MyLog\n    Load 'MyLog' into the Main Log machine\n\n rdairplay --log2=MyLog:14+\n    Load 'MyLog' into the Aux Log 1 machine, 'Make Next'\n    to line 14 and then start the log.\n\n rdairplay --log1=YourLog --log2=MyLog\n    Load 'YourLog' into the Main Log machine and 'MyLog' into the\n    Aux Log 1 machine.\n"
 
+
 class MainWidget : public QWidget
 {
   Q_OBJECT
@@ -87,7 +88,7 @@ class MainWidget : public QWidget
   QSizePolicy sizePolicy() const;
 
  private slots:
-  void logLine (QString);
+  void logLine(RDConfig::LogPriority prio,const QString &msg);
   void ripcConnected(bool state);
   void rmlReceivedData(RDMacro *rml);
   void logRenamedData(int log);
@@ -122,7 +123,6 @@ class MainWidget : public QWidget
   void SetLiveAssistMode();
   void SetActionMode(StartButton::Mode mode);
   bool FirstPort(int index);
-  RDConfig *air_config;
   bool GetPanel(QString str,RDAirPlayConf::PanelType *type,int *panel);
   QFont MessageFont(QString str);
   LogPlay *air_log[RDAIRPLAY_LOG_QUANTITY];
@@ -175,6 +175,7 @@ class MainWidget : public QWidget
   RDAirPlayConf::ExitCode rdairplay_previous_exit_code;
   QDateTime air_startup_datetime;
   RDLabel *air_refresh_label;
+  QPixmap *air_refresh_pixmap;
   QString air_editor_cmd;
 };
 
