@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdpanel.cpp,v 1.15 2007/12/31 18:49:12 fredg Exp $
+//      $Id: rdpanel.cpp,v 1.19 2008-04-22 18:14:38 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,6 +28,9 @@
 
 #include <qmessagebox.h>
 #include <qapplication.h>
+#include <qtranslator.h>
+#include <qtextcodec.h>
+#include <qpainter.h>
 
 #include <rdpanel.h>
 #include <rd.h>
@@ -44,6 +47,7 @@ RDAirPlayConf *rdairplay_conf;
 RDAudioPort *rdaudioport_conf;
 RDUser *rduser;
 RDRipc *rdripc;
+#include <rdcmd_switch.h>
 RDCartDialog *panel_cart_dialog;
 
 //
@@ -71,6 +75,10 @@ void SigHandler(int signo)
 MainWidget::MainWidget(QWidget *parent,const char *name)
   :QWidget(parent,name)
 {
+  QPixmap *pm;
+  QPainter *pd;
+  QPixmap *mainmap;
+
   //
   // Fix the Window Size
   //
@@ -81,6 +89,12 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   setMaximumHeight(sizeHint().height());
 #endif  // RESIZABLE
 
+  //
+  // Load the command-line arguments
+  //
+  RDCmdSwitch *cmd=new RDCmdSwitch(qApp->argc(),qApp->argv(),"rdpanel",
+				   RDPANEL_USAGE);
+
   //
   // Generate Fonts
   //
@@ -143,6 +157,15 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   rdstation_conf=new RDStation(panel_config->stationName());
   rdairplay_conf=new RDAirPlayConf(panel_config->stationName(),0,"RDPANEL");
+  panel_skin_pixmap=new QPixmap(rdairplay_conf->skinPath());
+  if(panel_skin_pixmap->isNull()||(panel_skin_pixmap->width()<1024)||
+     (panel_skin_pixmap->height()<738)) {
+    delete panel_skin_pixmap;
+    panel_skin_pixmap=NULL;
+  }
+  else {
+    setErasePixmap(*panel_skin_pixmap);
+  }
 
   //
   // RIPC Connection
@@ -197,6 +220,15 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
     panel_panel->setLogfile(panel_config->airplayLogname());
     panel_panel->setGeometry(10,10,panel_panel->sizeHint().width(),
 			 panel_panel->sizeHint().height());
+    if(panel_skin_pixmap!=NULL) {
+      pm=new QPixmap(1024,738);
+      pd=new QPainter(pm);
+      pd->drawPixmap(-10,-10,*panel_skin_pixmap);
+      pd->end();
+      panel_panel->setErasePixmap(*pm);
+      delete pd;
+      delete pm;
+    }
     panel_panel->setPauseEnabled(rdairplay_conf->panelPauseEnabled());
     panel_panel->setCard(0,rdairplay_conf->card(2));
     panel_panel->setPort(0,rdairplay_conf->port(2));
@@ -364,6 +396,28 @@ int main(int argc,char *argv[])
 {
   QApplication a(argc,argv);
   
+  //
+  // Load Translations
+  //
+  QTranslator qt(0);
+  qt.load(QString(QTDIR)+QString("/translations/qt_")+QTextCodec::locale(),".");
+  a.installTranslator(&qt);
+
+  QTranslator rd(0);
+  rd.load(QString(PREFIX)+QString("/share/rivendell/librd_")+
+	     QTextCodec::locale(),".");
+  a.installTranslator(&rd);
+
+  QTranslator rdhpi(0);
+  rdhpi.load(QString(PREFIX)+QString("/share/rivendell/librdhpi_")+
+	     QTextCodec::locale(),".");
+  a.installTranslator(&rdhpi);
+
+  QTranslator tr(0);
+  tr.load(QString(PREFIX)+QString("/share/rivendell/rdpanel_")+
+	     QTextCodec::locale(),".");
+  a.installTranslator(&tr);
+
   MainWidget *w=new MainWidget(NULL,"main");
   a.setMainWidget(w);
   w->setGeometry(QRect(QPoint(0,0),w->sizeHint()));
