@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdimport.cpp,v 1.20 2007/09/14 14:07:02 fredg Exp $
+//      $Id: rdimport.cpp,v 1.22 2008-08-05 16:20:45 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,6 +33,7 @@
 #include <qdir.h>
 
 #include <rd.h>
+#include <rdcut.h>
 #include <rdconf.h>
 #include <rdimport.h>
 #include <rdlibrary_conf.h>
@@ -472,13 +473,13 @@ void MainObject::ProcessFileList(const QString &flist)
   QString entry;
 
   for(unsigned i=0;i<flist.length();i++) {
-    if(flist.at(i)==',') {
-      ProcessFileEntry(entry);
-      entry="";
-    }
-    else {
+//    if(flist.at(i)==',') {
+//      ProcessFileEntry(entry);
+//      entry="";
+//    }
+//    else {
       entry+=flist.at(i);
-    }
+//    }
   }
   ProcessFileEntry(entry);
 }
@@ -495,7 +496,7 @@ void MainObject::ProcessFileEntry(const QString &entry)
   }
   globbuf.gl_offs=RDIMPORT_GLOB_SIZE;
   while((globbuf.gl_pathc==RDIMPORT_GLOB_SIZE)||(gflags==GLOB_MARK)) {
-    glob(entry,gflags,NULL,&globbuf);
+    glob(RDEscapeString(entry),gflags,NULL,&globbuf);
     if((globbuf.gl_pathc==0)&&(gflags==GLOB_MARK)&&(!import_drop_box)) {
       PrintLogDateTime(stderr);
       fprintf(stderr," Unable to open \"%s\", skipping...\n",
@@ -680,7 +681,7 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
   QString cmd;
   if(import_normalization_level==0) {
     cmd=QString().
-      sprintf("rd_import_file 0 %d %d %s %d %d %d %d %s/%s.%s %s %s",
+      sprintf("rd_import_file 0 %d %d %s %d %d %d %d %s %s %s",
 	      format_in,
 	      wavefile->getSamplesPerSec(),
 	      (const char *)RDEscapeString(effective_filename).utf8(),  
@@ -688,15 +689,13 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
 	      import_channels,
 	      import_samprate,
 	      import_channels*import_bitrate/1000,
-	      (const char *)RD_AUDIO_ROOT,
-	      (const char *)cut->cutName(),
-	      (const char *)RD_AUDIO_EXTENSION,
+	      RDCut::pathName(cut->cutName()).ascii(), 
 	      (const char *)tempdat_name,
 	      (const char *)tempwav_name);
   }
   else {
     cmd=QString().
-      sprintf("rd_import_file %6.4f %d %d %s %d %d %d %d %s/%s.%s %s %s",
+      sprintf("rd_import_file %6.4f %d %d %s %d %d %d %d %s %s %s",
 	      normal,
 	      format_in,
 	      wavefile->getSamplesPerSec(),
@@ -705,9 +704,7 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
 	      import_channels,
 	      import_samprate,
 	      import_channels*import_bitrate/1000,
-	      (const char *)RD_AUDIO_ROOT,
-	      (const char *)cut->cutName(),
-	      (const char *)RD_AUDIO_EXTENSION,
+	      RDCut::pathName(cut->cutName()).ascii(), 
 	      (const char *)tempdat_name,
 	      (const char *)tempwav_name);
   }
@@ -798,7 +795,7 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
   delete effective_group;
 
   if(import_delete_source) {
-    unlink(filename);
+    unlink(filename.utf8());
     if(import_verbose) {
       PrintLogDateTime();
       printf(" Deleted file \"%s\"\n",(const char *)RDGetBasePart(filename).utf8());
