@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rmlsend.cpp,v 1.4 2007/06/12 23:02:36 fredg Exp $
+//      $Id: rmlsend.cpp,v 1.5 2008-04-01 18:27:36 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -542,13 +542,17 @@ int main(int argc,char *argv[])
     qt.load(qt_path+QString("qt_")+QTextCodec::locale(),".");
     a.installTranslator(&qt);
     
-    QTranslator libradio(0);
-    libradio.load(tr_path+QString("libradio_")+QTextCodec::locale(),".");
-    a.installTranslator(&libradio);
+    QTranslator rd(0);
+    rd.load(tr_path+QString("librd_")+QTextCodec::locale(),".");
+    a.installTranslator(&rd);
     
-    QTranslator tests(0);
-    tests.load(tr_path+QString("rmlsend_")+QTextCodec::locale(),".");
-    a.installTranslator(&tests);
+    QTranslator rdhpi(0);
+    rdhpi.load(tr_path+QString("librdhpi_")+QTextCodec::locale(),".");
+    a.installTranslator(&rdhpi);
+
+    QTranslator tr(0);
+    tr.load(tr_path+QString("rmlsend_")+QTextCodec::locale(),".");
+    a.installTranslator(&tr);
     
     //
     // Start Event Loop
